==> kubernetes-model-admissionregistration-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/WebhookClientConfigBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WebhookClientConfigBuilder extends WebhookClientConfigFluentImpl<WebhookClientConfigBuilder> implements VisitableBuilder<WebhookClientConfig,WebhookClientConfigBuilder>{
  public WebhookClientConfigBuilder() {
    this(false);
  }
  public WebhookClientConfigBuilder(Boolean validationEnabled) {
    this(new WebhookClientConfig(), validationEnabled);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WebhookClientConfig(), validationEnabled);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent,WebhookClientConfig instance) {
    this(fluent, instance, false);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent,WebhookClientConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withCaBundle(instance.getCaBundle());
      fluent.withService(instance.getService());
      fluent.withUrl(instance.getUrl());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WebhookClientConfigBuilder(WebhookClientConfig instance) {
    this(instance,false);
  }
  public WebhookClientConfigBuilder(WebhookClientConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withCaBundle(instance.getCaBundle());
      this.withService(instance.getService());
      this.withUrl(instance.getUrl());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  WebhookClientConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WebhookClientConfig build() {
    WebhookClientConfig buildable = new WebhookClientConfig(fluent.getCaBundle(),fluent.getService(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> kubernetes-model-admissionregistration-6.8.0-sources.jar: io/fabric8/kubernetes/api/model/admissionregistration/v1/WebhookClientConfigBuilder.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WebhookClientConfigBuilder extends WebhookClientConfigFluent<WebhookClientConfigBuilder> implements VisitableBuilder<WebhookClientConfig,WebhookClientConfigBuilder>{
  public WebhookClientConfigBuilder() {
    this(false);
  }
  public WebhookClientConfigBuilder(Boolean validationEnabled) {
    this(new WebhookClientConfig(), validationEnabled);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WebhookClientConfig(), validationEnabled);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent,WebhookClientConfig instance) {
    this(fluent, instance, false);
  }
  public WebhookClientConfigBuilder(WebhookClientConfigFluent<?> fluent,WebhookClientConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new WebhookClientConfig());

    if (instance != null) {
      fluent.withCaBundle(instance.getCaBundle());
      fluent.withService(instance.getService());
      fluent.withUrl(instance.getUrl());
      fluent.withCaBundle(instance.getCaBundle());
      fluent.withService(instance.getService());
      fluent.withUrl(instance.getUrl());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WebhookClientConfigBuilder(WebhookClientConfig instance) {
    this(instance,false);
  }
  public WebhookClientConfigBuilder(WebhookClientConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new WebhookClientConfig());

    if (instance != null) {
      this.withCaBundle(instance.getCaBundle());
      this.withService(instance.getService());
      this.withUrl(instance.getUrl());
      this.withCaBundle(instance.getCaBundle());
      this.withService(instance.getService());
      this.withUrl(instance.getUrl());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  WebhookClientConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WebhookClientConfig build() {
    WebhookClientConfig buildable = new WebhookClientConfig(fluent.getCaBundle(),fluent.buildService(),fluent.getUrl());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
